import os
import sys
sys.path.insert(0, os.path.abspath('..'))

import jenkins  # noqa
